@@ -73,14 +73,23 @@ def main():
               'mapname': d.gamestate.config['serverinfo']['mapname'],
               'duration': duration}
 
-    if d.scores:
-        output['scores'] = d.scores[-1]
-    elif int(d.gamestate.config['serverinfo']['g_gametype']) >= GT_TEAM:
-        output['scores']={}
-        output['scores']['TEAM_RED'] = {
-            'score': d.gamestate.config['scores1'].strip('"')}
-        output['scores']['TEAM_BLUE'] = {
-            'score': d.gamestate.config['scores2'].strip('"')}
+    output['scores'] = d.scores[-1] if d.scores else {}
+
+    if int(d.gamestate.config['serverinfo']['g_gametype']) >= GT_TEAM:
+        output['scores']['TEAM_RED'] = {}
+        output['scores']['TEAM_BLUE'] = {}
+        output['scores']['TEAM_RED']['score'] = d.gamestate.config['scores1'].strip('"')
+        output['scores']['TEAM_BLUE']['score'] = d.gamestate.config['scores2'].strip('"')
+    else:
+        if not d.gamestate.config['1stplayer'] in output['scores']:
+            output['scores'][d.gamestate.config['1stplayer']] = {}
+        if not d.gamestate.config['2ndplayer'] in output['scores']:
+            output['scores'][d.gamestate.config['2ndplayer']] = {}
+        output['scores'][d.gamestate.config['1stplayer']]['score'] = d.gamestate.config['scores1'].strip('"')
+        output['scores'][d.gamestate.config['2ndplayer']]['score'] = d.gamestate.config['scores2'].strip('"')
+        victor = d.gamestate.config['1stplayer'] if int(output['scores'][d.gamestate.config['1stplayer']]['score']) > int(output['scores'][d.gamestate.config['2ndplayer']]['score']) else None
+        victor = d.gamestate.config['2ndplayer'] if int(output['scores'][d.gamestate.config['2ndplayer']]['score']) > int(output['scores'][d.gamestate.config['1stplayer']]['score']) else victor
+        output['victor'] = victor
 
     if int(d.gamestate.config['serverinfo']['g_gametype']) >= GT_TEAM:
         output['teams'] = {}
@@ -94,14 +103,8 @@ def main():
         output['teams']['TEAM_BLUE']['clan'] = d.gamestate.config['blueteamclantag']
         output['teams']['TEAM_BLUE']['timeouts_left'] = d.gamestate.config['timeouts_blue']
         output['teams']['TEAM_BLUE']['score'] = output['scores']['TEAM_BLUE']
-        victor = 'TEAM_RED' if int(output['scores']['TEAM_RED']) > int(output['scores']['TEAM_BLUE']) else None
-        victor = 'TEAM_BLUE' if int(output['scores']['TEAM_BLUE']) > int(output['scores']['TEAM_RED']) else victor
-        output['victor'] = victor
-    else: # DUEL, likely doesn't work for FFA
-        output['scores'][d.gamestate.config['1stplayer']]['score'] = d.gamestate.config['scores1'].strip('"')
-        output['scores'][d.gamestate.config['2ndplayer']]['score'] = d.gamestate.config['scores2'].strip('"')
-        victor = d.gamestate.config['1stplayer'] if int(output['scores'][d.gamestate.config['1stplayer']]['score']) > int(output['scores'][d.gamestate.config['2ndplayer']]['score']) else None
-        victor = d.gamestate.config['2ndplayer'] if int(output['scores'][d.gamestate.config['2ndplayer']]['score']) > int(output['scores'][d.gamestate.config['1stplayer']]['score']) else victor
+        victor = 'TEAM_RED' if int(output['scores']['TEAM_RED']['score']) > int(output['scores']['TEAM_BLUE']['score']) else None
+        victor = 'TEAM_BLUE' if int(output['scores']['TEAM_BLUE']['score']) > int(output['scores']['TEAM_RED']['score']) else victor
         output['victor'] = victor
 
     json.dump(output, 
